@@ -26,23 +26,17 @@
 #include "model/kgpgitemnode.h"
 #include "transactions/kgpgchangepass.h"
 
-#include <KComboBox>
-#include <KDatePicker>
 #include <KGlobal>
 #include <KLocale>
 #include <KMessageBox>
 #include <KPushButton>
 #include <KToolInvocation>
-#include <KUrlLabel>
 #include <QApplication>
 #include <QCheckBox>
 #include <QFormLayout>
-#include <QGridLayout>
-#include <QGroupBox>
 #include <QHBoxLayout>
 #include <QImage>
 #include <QPixmap>
-#include <QVBoxLayout>
 
 using namespace KgpgCore;
 
@@ -171,7 +165,7 @@ void KgpgKeyInfo::reloadNode()
 void KgpgKeyInfo::displayKey()
 {
     const QString name = m_node->getName();
-    setCaption(name);
+    setWindowTitle(name);
     m_name->setText(QLatin1String( "<qt><b>" ) + name + QLatin1String( "</b></qt>" ));
 
     const QString email = m_node->getEmail();
@@ -388,5 +382,3 @@ void KgpgKeyInfo::slotKeyExpanded()
 	if (hasphoto)
 		slotLoadPhoto(m_photoid->currentText());
 }
-
-#include "keyinfodialog.moc"
