@@ -27,6 +27,7 @@
 #include <KLocale>
 #include <KMessageBox>
 #include <KStandardDirs>
+#include <KUrl>
 #include <KUrlRequester>
 #include <QCheckBox>
 #include <QGridLayout>
@@ -41,7 +42,7 @@ using namespace KgpgCore;
 KGpgFirstAssistant::KGpgFirstAssistant(QWidget *parent)
 		: KAssistantDialog(parent)
 {
-	setCaption(i18n("KGpg Assistant"));
+	setWindowTitle(i18n("KGpg Assistant"));
 
 	QWidget *page = new QWidget(this);
 	QGridLayout *gridLayout = new QGridLayout(page);
@@ -371,5 +372,3 @@ KGpgFirstAssistant::slotBinaryChanged(const QString &binary)
 		}
 	}
 }
-
-#include "kgpgfirstassistant.moc"
