@@ -23,9 +23,6 @@
 #include "core/KGpgUidNode.h"
 
 #include <gpgme.h>
-#include <KConfig>
-#include <KDebug>
-#include <KGlobal>
 #include <KLocale>
 #include <KMessageBox>
 #include <KProcess>
@@ -416,5 +413,3 @@ KgpgKeyList KgpgInterface::readSecretKeys(const QStringList &ids)
 
 	return result;
 }
-
-#include "kgpginterface.moc"
